@@ -1,9 +1,9 @@
 package Egg::Component;
 #
 # Copyright 2006 Bee Flag, Corp. All Rights Reserved.
-# Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
+# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: Component.pm 235 2007-02-23 13:18:49Z lushe $
+# $Id: Component.pm 245 2007-02-24 18:21:27Z lushe $
 #
 use strict;
 use base qw/Class::Accessor::Fast/;
@@ -105,7 +105,7 @@ L<Egg::Release>,
 
 =head1 AUTHOR
 
-Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>
+Masatoshi Mizuno, E<lt>lusheE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
